==> haskell-base-orphans-0.8.4-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-orphans
version:              0.8.4
visibility:           public
id:                   base-orphans-0.8.4-JVJ8ttw51H7Dc3tJYgx6uK
key:                  base-orphans-0.8.4-JVJ8ttw51H7Dc3tJYgx6uK
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  876c16b9a07d7f65d9de08d0f731061d
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-8.10.3/site-local/base-orphans-0.8.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/base-orphans-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/base-orphans-0.8.4
hs-libraries:         HSbase-orphans-0.8.4-JVJ8ttw51H7Dc3tJYgx6uK
depends:              base-4.14.1.0 ghc-prim-0.6.1
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.8.4-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-orphans
version:              0.8.4
visibility:           public
id:                   base-orphans-0.8.4-6Z8Eg84NK7u5UGWcrnUfUX
key:                  base-orphans-0.8.4-6Z8Eg84NK7u5UGWcrnUfUX
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  642459550eb14e947995130ea093ee07
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/base-orphans-0.8.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/base-orphans-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/base-orphans-0.8.4
hs-libraries:         HSbase-orphans-0.8.4-6Z8Eg84NK7u5UGWcrnUfUX
depends:              base-4.14.1.0 ghc-prim-0.6.1
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
